@@ -444,13 +444,14 @@ class S3Client {
     }
 
     private function initiateMultipartUpload($bucket, $key) {
-        $url = $this->buildUrl($bucket, $key) . '?uploads=';
+        $url = $this->buildUrl($bucket, $key) . '?uploads';
         // Use empty payload hash for multipart initiate (required by AWS spec)
         $emptyPayloadHash = 'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855';
-        $headers = $this->buildHeaders('POST', $bucket, $key, 'uploads=', 'application/octet-stream', $emptyPayloadHash, 0);
+        $headers = $this->buildHeaders('POST', $bucket, $key, 'uploads', 'application/octet-stream', $emptyPayloadHash, 0);
 
-        // Log the exact URL for debugging
+        // Log the exact URL and headers for debugging
         error_log("Multipart initiate URL: {$url}");
+        error_log("Multipart initiate headers: " . print_r($headers, true));
 
         $ch = curl_init();
         curl_setopt($ch, CURLOPT_URL, $url);
